==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRedirectDerivePortFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRedirectDerivePortFluent<A extends HTTPRedirectDerivePortFluent<A>> extends BaseFluent<A>{
  public HTTPRedirectDerivePortFluent() {
  }
  public HTTPRedirectDerivePortFluent(HTTPRedirectDerivePort instance) {
    instance = (instance != null ? instance : new HTTPRedirectDerivePort());

    if (instance != null) {
      this.withDerivePort(instance.getDerivePort());
      this.withDerivePort(instance.getDerivePort());
    }
  }
  private HTTPRedirectRedirectPortSelection derivePort;
  public HTTPRedirectRedirectPortSelection getDerivePort() {
    return this.derivePort;
  }
  public A withDerivePort(HTTPRedirectRedirectPortSelection derivePort) {
    this.derivePort=derivePort; return (A) this;
  }
  public boolean hasDerivePort() {
    return this.derivePort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRedirectDerivePortFluent that = (HTTPRedirectDerivePortFluent) o;
    if (!java.util.Objects.equals(derivePort, that.derivePort)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(derivePort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (derivePort != null) { sb.append("derivePort:"); sb.append(derivePort); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRedirectDerivePortFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPRedirectDerivePortFluent<A extends HTTPRedirectDerivePortFluent<A>> extends BaseFluent<A>{
  public HTTPRedirectDerivePortFluent() {
  }
  
  public HTTPRedirectDerivePortFluent(HTTPRedirectDerivePort instance) {
    this.copyInstance(instance);
  }
  private HTTPRedirectRedirectPortSelection derivePort;
  
  protected void copyInstance(HTTPRedirectDerivePort instance) {
    instance = (instance != null ? instance : new HTTPRedirectDerivePort());
  
    if (instance != null) {
        this.withDerivePort(instance.getDerivePort());
        this.withDerivePort(instance.getDerivePort());
      }
  }
  
  public HTTPRedirectRedirectPortSelection getDerivePort() {
    return this.derivePort;
  }
  
  public A withDerivePort(HTTPRedirectRedirectPortSelection derivePort) {
    this.derivePort=derivePort; return (A) this;
  }
  
  public boolean hasDerivePort() {
    return this.derivePort != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRedirectDerivePortFluent that = (HTTPRedirectDerivePortFluent) o;
    if (!java.util.Objects.equals(derivePort, that.derivePort)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(derivePort,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (derivePort != null) { sb.append("derivePort:"); sb.append(derivePort); }
    sb.append("}");
    return sb.toString();
  }
  

}
